@@ -2,7 +2,7 @@
 package Perl::Structure;
 use strict;
 use warnings;
-use Perl::Types;
+use Perl::Config;  # don't use Perl::Types inside itself, in order to avoid circular includes
 our $VERSION = 0.002_000;
 
 # [[[ OO INHERITANCE ]]]
