@@ -2,7 +2,7 @@
 package Perl::Structure::Hash::SubTypes1D;
 use strict;
 use warnings;
-use Perl::Types;
+use Perl::Config;  # don't use Perl::Types inside itself, in order to avoid circular includes
 our $VERSION = 0.018_000;
 
 # [[[ CRITICS ]]]
@@ -11,6 +11,9 @@ our $VERSION = 0.018_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 ## no critic qw(Capitalization ProhibitMultiplePackages ProhibitReusedNames)  # SYSTEM DEFAULT 3: allow multiple & lower case package names
 
+# [[[ INCLUDES ]]]
+use Perl::Type::Integer;  # for integer_CHECKTRACE(), used in hashref_TYPE_typetest1()
+
 # [[[ EXPORTS ]]]
 # DEV NOTE, CORRELATION #rp051: hard-coded list of RPerl data types and data structures
 use Exporter 'import';
@@ -46,9 +49,6 @@ our @EXPORT_OK = qw(
     hashref_string_typetest1
 );
 
-# [[[ INCLUDES ]]]
-use Perl::Type::Integer;  # for integer_CHECKTRACE(), used in hashref_TYPE_typetest1()
-
 # [[[ HASH REF INTEGER ]]]
 # [[[ HASH REF INTEGER ]]]
 # [[[ HASH REF INTEGER ]]]
