@@ -2,7 +2,7 @@
 package Perl::Type;
 use strict;
 use warnings;
-#use Perl::Types;  # don't use Perl::Types inside itself, in order to avoid circular includes
+use Perl::Config;  # don't use Perl::Types inside itself, in order to avoid circular includes
 our $VERSION = 0.002_000;
 
 # [[[ OO INHERITANCE ]]]
