@@ -6,9 +6,9 @@
 # <<< EXECUTE_SUCCESS: 'have $greeting_final = howdy' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
