@@ -3,10 +3,10 @@
 # <<< PARSE_ERROR: 'Unrecognized escape \T passed through' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 package Perl::Types::Test::LiteralString::Package_DoubleQuotes_11_Bad;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
