@@ -3,10 +3,10 @@
 # <<< PARSE_ERROR: 'Can't modify constant item in scalar assignment' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 package Perl::Types::Test::Properties::Class_00_Bad_07;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ OO INHERITANCE ]]]
@@ -18,6 +18,6 @@ our hashref $properties
     = { empty_property = my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-sub empty_method { { my integer::method $RETURN_TYPE }; return 2; }
+sub empty_method { { my integer $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
